# Handy Tools

## Handy Tools For Your Django Project

### provided tools: models, utils, context processors, templates, template tags

## install

`pip install django-handytools`

> consider --user option
